@@ -60,6 +60,7 @@ LinearDiscriminantAnalysisModel <- function(SplitRatio = 0.8,
                             data = training_fold,
                             na.action = na.omit)
     y_pred <- predict(classifier, newdata = test_fold[-fac])$class
+    conta <- table(test_fold[, fac], y_pred)
     result <- ConfusionMatrix(test_fold[, fac], y_pred)
     if(!is.null(NewData)) {
     y_pred_NewData <- predict(classifier, newdata = NewData)$class
@@ -67,7 +68,7 @@ LinearDiscriminantAnalysisModel <- function(SplitRatio = 0.8,
     } else {
       y_pred_NewData <- NULL
     }
-    allresult <- list(result = result, pnewdata = y_pred_NewData)
+    allresult <- list(ConfusionMat = conta, result = result, pnewdata = y_pred_NewData)
     return(allresult)
   }, mc.cores = NCores)
 }
